@@ -29,7 +29,7 @@ class ParserError(ValueError):
 
 _modeError = ParserError("You're trying to open an Affymetrix v4"
                          " CEL file. You have to use a read binary mode,"
-                         " like this `open(filename \"rb\")`.")
+                         " like this: open(filename, 'rb')")
 
 # for debugging
 # import pprint
@@ -164,14 +164,14 @@ def read_v4(f):
     # http://www.affymetrix.com/estore/support/developer/powertools/changelog/gcos-agcc/cel.html.affx
     record = Record()
     preHeaders = ["magic", "version", "columns", "rows", "cellNo", "headerLen"]
-    preHeadersMap = dict()
-    headersMap = dict()
+    preHeadersMap = {}
+    headersMap = {}
 
     # load pre-headers
     try:
         for name in preHeaders:
             preHeadersMap[name] = struct.unpack("<i", f.read(4))[0]
-    except UnicodeDecodeError as e:
+    except UnicodeDecodeError:
         raise _modeError
 
     char = f.read(preHeadersMap["headerLen"])
@@ -232,7 +232,7 @@ def read_v4(f):
     raiseBadHeader("OffsetY", 0)
 
     # This is unfortunately undocumented, but it turns out that real data has
-    # the `record.AlgorithmParameters` repeated in the data section, until an
+    # the record.AlgorithmParameters repeated in the data section, until an
     # EOF, i.e. b"\x04".
     char = b"\x00"
     safetyValve = 10**4
