@@ -1,8 +1,9 @@
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+# Copyright 2012 by Leighton Pritchard.  All rights reserved.
 #
-
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """Generate RGB colours suitable for distinguishing categorical data.
 
 This module provides a class that implements a spiral 'path' through HSV
@@ -19,9 +20,9 @@ categories to be coloured).
 """
 
 # standard library
-import colorsys    # colour format conversions
+import colorsys  # colour format conversions
 from math import log, exp, floor, pi
-import random      # for jitter values
+import random  # for jitter values
 
 
 class ColorSpiral(object):
@@ -48,8 +49,7 @@ class ColorSpiral(object):
     path.
     """
 
-    def __init__(self, a=1, b=0.33, v_init=0.85, v_final=0.5,
-                 jitter=0.05):
+    def __init__(self, a=1, b=0.33, v_init=0.85, v_final=0.5, jitter=0.05):
         """Initialize a logarithmic spiral path through HSV colour space.
 
         Arguments:
@@ -93,14 +93,15 @@ class ColorSpiral(object):
         for n in range(1, k + 1):
             # For each value of n, t indicates the angle through which the
             # spiral has turned, to this point
-            t = (1. / self._b) * (log(n + (k * offset)) -
-                                  log((1 + offset) * k * self._a))
+            t = (1.0 / self._b) * (
+                log(n + (k * offset)) - log((1 + offset) * k * self._a)
+            )
             # Put 0 <= h <= 2*pi, where h is the angular part of the polar
             # co-ordinates for this point on the spiral
             h = t
             while h < 0:
                 h += 2 * pi
-            h = (h - (floor(h / (2 * pi)) * pi))
+            h = h - (floor(h / (2 * pi)) * pi)
             # Now put h in [0, 1] for colorsys conversion
             h = h / (2 * pi)
             # r is the radial distance of this point from the centre
@@ -147,16 +148,29 @@ class ColorSpiral(object):
     def _set_jitter(self, value):
         self._jitter = max(0, min(1, value))
 
-    a = property(_get_a, _set_a,
-                 doc="Parameter controlling initial spiral direction (a > 0)")
-    b = property(_get_b, _set_b,
-                 doc="Parameter controlling rate spiral revolves around axis (b > 0)")
-    v_init = property(_get_v_init, _set_v_init,
-                      doc="Initial value of V (brightness) for the spiral (range 0 to 1)")
-    v_final = property(_get_v_final, _set_v_final,
-                       doc="Final value of V (brightness) for the spiral (range 0 to 1)")
-    jitter = property(_get_jitter, _set_jitter,
-                      doc="Degree of V (brightness) jitter to add to each color (range 0 to 1)")
+    a = property(
+        _get_a, _set_a, doc="Parameter controlling initial spiral direction (a > 0)"
+    )
+    b = property(
+        _get_b,
+        _set_b,
+        doc="Parameter controlling rate spiral revolves around axis (b > 0)",
+    )
+    v_init = property(
+        _get_v_init,
+        _set_v_init,
+        doc="Initial value of V (brightness) for the spiral (range 0 to 1)",
+    )
+    v_final = property(
+        _get_v_final,
+        _set_v_final,
+        doc="Final value of V (brightness) for the spiral (range 0 to 1)",
+    )
+    jitter = property(
+        _get_jitter,
+        _set_jitter,
+        doc="Degree of V (brightness) jitter to add to each color (range 0 to 1)",
+    )
 
 
 # Convenience functions for those who don't want to bother with a
