@@ -1,12 +1,14 @@
 # Copyright 2003-2008 by Leighton Pritchard.  All rights reserved.
 # Revisions copyright 2008-2010 by Peter Cock.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
 #
-# Contact:       Leighton Pritchard, Scottish Crop Research Institute,
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
+#
+# Contact:       Leighton Pritchard, The James Hutton Institute,
 #                Invergowrie, Dundee, Scotland, DD2 5DA, UK
-#                L.Pritchard@scri.ac.uk
+#                Leighton.Pritchard@hutton.ac.uk
 ################################################################################
 #
 # TODO: Make representation of Ymax and Ymin values at this level, so that
@@ -45,14 +47,24 @@ class GraphSet(object):
          - name      String identifying the graph set sensibly
 
         """
-        self.id = id            # Unique identifier for the set
-        self._next_id = 0       # Holds unique ids for graphs
-        self._graphs = {}       # Holds graphs, keyed by unique id
-        self.name = name        # Holds description of graph
+        self.id = id  # Unique identifier for the set
+        self._next_id = 0  # Holds unique ids for graphs
+        self._graphs = {}  # Holds graphs, keyed by unique id
+        self.name = name  # Holds description of graph
 
-    def new_graph(self, data, name=None, style='bar', color=colors.lightgreen,
-                  altcolor=colors.darkseagreen, linewidth=1, center=None,
-                  colour=None, altcolour=None, centre=None):
+    def new_graph(
+        self,
+        data,
+        name=None,
+        style="bar",
+        color=colors.lightgreen,
+        altcolor=colors.darkseagreen,
+        linewidth=1,
+        center=None,
+        colour=None,
+        altcolour=None,
+        centre=None,
+    ):
         """Add a GraphData object to the diagram.
 
         Arguments:
@@ -81,11 +93,11 @@ class GraphSet(object):
         if centre is not None:
             center = centre
 
-        id = self._next_id                              # get id number
+        id = self._next_id  # get id number
         graph = GraphData(id, data, name, style, color, altcolor, center)
         graph.linewidth = linewidth
-        self._graphs[id] = graph                        # add graph data
-        self._next_id += 1                              # increment next id
+        self._graphs[id] = graph  # add graph data
+        self._next_id += 1  # increment next id
         return graph
 
     def del_graph(self, graph_id):
@@ -119,8 +131,13 @@ class GraphSet(object):
             data += list(graph.data.values())
         data.sort()
         datalen = len(data)
-        return(data[0], data[datalen / 4], data[datalen / 2],
-               data[3 * datalen / 4], data[-1])
+        return (
+            data[0],
+            data[datalen / 4],
+            data[datalen / 2],
+            data[3 * datalen / 4],
+            data[-1],
+        )
 
     def to_string(self, verbose=0):
         """Return a formatted string with information about the set.
@@ -153,21 +170,3 @@ class GraphSet(object):
         outstr.append("%d graphs" % len(self._graphs))
         outstr = "\n".join(outstr)
         return outstr
-
-
-################################################################################
-# RUN AS SCRIPT
-################################################################################
-
-if __name__ == '__main__':
-
-    # Test code
-    gdgs = GraphSet(0, 'test data')
-
-    testdata1 = [(1, 10), (5, 15), (10, 20), (20, 40)]
-    testdata2 = [(250, .34), (251, .7), (252, .7), (253, .54), (254, .65)]
-
-    gdgs.add_graph(testdata1, 'TestData 1')
-    gdgs.add_graph(testdata2, 'TestData 2')
-
-    print(gdgs)
