@@ -1,8 +1,10 @@
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+# Copyright 2002 by Jeffrey Chang.
+# All rights reserved.
 #
-
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """A state-emitting MarkovModel.
 
 Note terminology similar to Manning and Schutze is used.
@@ -129,17 +131,17 @@ def save(mm, handle):
     """Save MarkovModel object into handle."""
     # This will fail if there are spaces in the states or alphabet.
     w = handle.write
-    w("STATES: %s\n" % ' '.join(mm.states))
-    w("ALPHABET: %s\n" % ' '.join(mm.alphabet))
+    w("STATES: %s\n" % " ".join(mm.states))
+    w("ALPHABET: %s\n" % " ".join(mm.alphabet))
     w("INITIAL:\n")
     for i in range(len(mm.p_initial)):
         w("  %s: %g\n" % (mm.states[i], mm.p_initial[i]))
     w("TRANSITION:\n")
     for i in range(len(mm.p_transition)):
-        w("  %s: %s\n" % (mm.states[i], ' '.join(str(x) for x in mm.p_transition[i])))
+        w("  %s: %s\n" % (mm.states[i], " ".join(str(x) for x in mm.p_transition[i])))
     w("EMISSION:\n")
     for i in range(len(mm.p_emission)):
-        w("  %s: %s\n" % (mm.states[i], ' '.join(str(x) for x in mm.p_emission[i])))
+        w("  %s: %s\n" % (mm.states[i], " ".join(str(x) for x in mm.p_emission[i])))
 
 
 # XXX allow them to specify starting points
@@ -174,13 +176,11 @@ def train_bw(states, alphabet, training_data,
     if pseudo_transition is not None:
         pseudo_transition = numpy.asarray(pseudo_transition)
         if pseudo_transition.shape != (N, N):
-            raise ValueError("pseudo_transition not shape " +
-                             "len(states) X len(states)")
+            raise ValueError("pseudo_transition not shape len(states) X len(states)")
     if pseudo_emission is not None:
         pseudo_emission = numpy.asarray(pseudo_emission)
         if pseudo_emission.shape != (N, M):
-            raise ValueError("pseudo_emission not shape " +
-                             "len(states) X len(alphabet)")
+            raise ValueError("pseudo_emission not shape len(states) X len(alphabet)")
 
     # Training data is given as a list of members of the alphabet.
     # Replace those with indexes into the alphabet list for easier
@@ -419,13 +419,11 @@ def train_visible(states, alphabet, training_data,
     if pseudo_transition is not None:
         pseudo_transition = numpy.asarray(pseudo_transition)
         if pseudo_transition.shape != (N, N):
-            raise ValueError("pseudo_transition not shape " +
-                             "len(states) X len(states)")
+            raise ValueError("pseudo_transition not shape len(states) X len(states)")
     if pseudo_emission is not None:
         pseudo_emission = numpy.asarray(pseudo_emission)
         if pseudo_emission.shape != (N, M):
-            raise ValueError("pseudo_emission not shape " +
-                             "len(states) X len(alphabet)")
+            raise ValueError("pseudo_emission not shape len(states) X len(alphabet)")
 
     # Training data is given as a list of members of the alphabet.
     # Replace those with indexes into the alphabet list for easier
