@@ -115,7 +115,7 @@ if sys.version_info[0] >= 3:
             # "ISO-8859-1" is also known as 'latin-1'
             # See the following for more detail:
             # https://www.w3.org/Protocols/rfc2616/rfc2616-sec3.html#sec3.7.1
-            encoding = 'latin-1'
+            encoding = "latin-1"
         wrapped = io.TextIOWrapper(io.BufferedReader(handle), encoding=encoding)
         try:
             # If wrapping an online handle, this is nice to have:
@@ -135,6 +135,14 @@ if sys.version_info[0] >= 3:
     from urllib.parse import urlencode, quote
     from urllib.error import URLError, HTTPError
 
+    exec("""\
+def raise_from(value, from_value):
+    try:
+        raise value from from_value
+    finally:
+        value = None
+""")
+
 else:
     # Python 2 code
     from __builtin__ import open, basestring, unicode
@@ -196,6 +204,9 @@ else:
     # Under urllib.error on Python 3:
     from urllib2 import URLError, HTTPError
 
+    def raise_from(value, from_value):
+        raise value
+
 
 if sys.platform == "win32":
     # Can't use commands.getoutput on Python 2, Unix only/broken:
